<?php
/**
 * Controller to handling insert & saving image data
 *
 * @package wp-image-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPImpr_Ajax_Insertimage' ))
{
  class IPImpr_Ajax_Insertimage
  {
    /**
     * Execution save options process
     *
     * @return void
     */
    public function exec()
    {
      $status   = 0;
      $message  = __( 'Failed to insert the image', IPIMPR_SLUG );
      $resultId = 0;
      $data     = array();

      if ( ! empty( $_POST['photo_id'] ) && ! empty( $_POST['photo_url'] ) && ! empty( $_POST['photo_type'] ) )
      {
        $photoUrl  = apply_filters( 'pre_link_url', $_POST['photo_url']  );
        $photoType = apply_filters( 'single_post_title', $_POST['photo_type']  );
        $filename  = apply_filters( 'pre_term_name', $_POST['filename']  );
        $photoId   = absint( $photoId );
        //
        //Get content image
        $content = @file_get_contents( $photoUrl );

        if ( ! empty( $content ) )
        {
          $supported = array( 'jpg', 'png', 'gif' );
          $_names    = explode( '.', $photoUrl );
          $fileext   = array_pop( $_names );
          if ( ! in_array( $fileext, $supported )) {
            $fileext = 'jpg';
          }

          $dirs   = wp_upload_dir();
          $base   = $dirs['path'];
          $path   = $base . '/' . $filename . '.' . $fileext;

          if ( file_exists( $path ))
          {
            $time = time();
            $path = $base . '/' . $filename . '-' . $time . '.' . $fileext;
          }
          //Save image
          file_put_contents( $path, $content );

          //Insert attachment
          $attData = array(
            'guid'           => $dirs['url'] . '/' . basename( $path ),
            'post_mime_type' => 'image/' . $fileext,
            'post_title'     => $filename,
            'post_content'   => '',
            'post_status'    => 'inherit'
          );
          if ( ! empty( $_POST['title'] ) && $_POST['title'] != '-' ) {
            $attData['post_title'] = apply_filters( 'single_post_title', $_POST['title']  );
          }
          if ( ! empty( $_POST['caption'] ) && $_POST['caption'] != '-' ) {
            $attData['post_excerpt'] = apply_filters( 'single_post_title', $_POST['caption']  );
          }
          if ( ! empty( $_POST['desc'] ) && $_POST['desc'] != '-' ) {
            $attData['post_content'] = $_POST['desc'];
          }

          $attach_id = wp_insert_attachment( $attData, $path );
          // Make sure that this file is included, as wp_generate_attachment_metadata() depends on it.
          require_once( ABSPATH . 'wp-admin/includes/image.php' );

          // Generate the metadata for the attachment, and update the database record.
          $attach_data = wp_generate_attachment_metadata( $attach_id, $path );
          wp_update_attachment_metadata( $attach_id, $attach_data );

          if ( ! empty( $_POST['alt'] ) && $_POST['alt'] != '-' ) {
            $alt = apply_filters( 'single_post_title', $_POST['alt']  );
            update_post_meta( $attach_id, '_wp_attachment_image_alt', $alt );
          }

          $status   = 1;
          $message  = __( 'Successfully saved the image.', IPIMPR_SLUG );
          $resultId = $attach_id;
          $data     = wp_prepare_attachment_for_js( $attach_id );
        }
      }

      echo json_encode( array(
        'status'    => $status,
        'message'   => $message,
        'id'        => $resultId,
        'data'      => $data
      ) );
      die();
    }

  }
}
